@@ -1,9 +1,9 @@
 BOLD = 0x02
 COLOR = 0x03
 ITALIC = 0x1D
-STRIKETHROUGH = 0x13
+STRIKETHROUGH = 0x1e
 RESET = 0x0f
-UNDERLINE = 0x15
+UNDERLINE = 0x1f
 MONOSPACE = 0x11
 
 WHITE = 0
